define(
//begin v1.x content
{
	"field-second-relative+0": "now",
	"field-quarter-relative+-1": "last quarter",
	"field-weekday": "day of the week",
	"field-mon-narrow-relative+0": "this M",
	"field-mon-narrow-relative+1": "next M",
	"field-weekOfMonth-short": "wk. of mo.",
	"field-weekday-short": "day of wk.",
	"field-wed-relative+0": "this Wednesday",
	"field-wed-relative+1": "next Wednesday",
	"field-dayperiod-short": "am/pm",
	"field-week-short": "wk.",
	"field-tue-relative+-1": "last Tuesday",
	"field-year-short": "yr.",
	"field-thu-narrow-relative+-1": "last Th",
	"field-hour-relative+0": "this hour",
	"field-fri-relative+-1": "last Friday",
	"field-hour-short": "hr.",
	"field-wed-relative+-1": "last Wednesday",
	"field-dayOfYear": "day of year",
	"field-mon-short-relative+-1": "last Mon.",
	"field-thu-relative+-1": "last Thursday",
	"field-era": "era",
	"field-sat-narrow-relative+0": "this Sa",
	"field-sat-narrow-relative+1": "next Sa",
	"field-year": "year",
	"field-hour": "hour",
	"field-sat-relative+0": "this Saturday",
	"field-sat-relative+1": "next Saturday",
	"field-sat-short-relative+-1": "last Sat.",
	"field-day-relative+0": "today",
	"field-day-relative+1": "tomorrow",
	"field-thu-relative+0": "this Thursday",
	"field-mon-narrow-relative+-1": "last M",
	"field-wed-narrow-relative+0": "this W",
	"field-thu-relative+1": "next Thursday",
	"field-wed-narrow-relative+1": "next W",
	"field-mon-short-relative+0": "this Mon.",
	"field-mon-short-relative+1": "next Mon.",
	"field-weekdayOfMonth-short": "wkday. of mo.",
	"field-wed-short-relative+-1": "last Wed.",
	"field-fri-narrow-relative+-1": "last F",
	"field-tue-short-relative+0": "this Tue.",
	"field-tue-short-relative+1": "next Tue.",
	"field-minute-short": "min.",
	"field-wed-short-relative+0": "this Wed.",
	"field-wed-short-relative+1": "next Wed.",
	"field-sun-relative+0": "this Sunday",
	"field-sun-relative+1": "next Sunday",
	"field-year-short-relative+0": "this yr.",
	"eraAbbr": [
		"Before R.O.C.",
		"Minguo"
	],
	"field-minute": "minute",
	"field-month-short": "mo.",
	"field-year-short-relative+1": "next yr.",
	"field-dayperiod": "am/pm",
	"field-day-relative+-1": "yesterday",
	"field-minute-relative+0": "this minute",
	"field-wed-narrow-relative+-1": "last W",
	"field-day-short": "day",
	"field-quarter-relative+0": "this quarter",
	"field-quarter-relative+1": "next quarter",
	"field-zone-short": "zone",
	"field-fri-relative+0": "this Friday",
	"field-fri-relative+1": "next Friday",
	"field-day": "day",
	"field-zone": "time zone",
	"field-year-relative+-1": "last year",
	"field-month-relative+-1": "last month",
	"field-thu-short-relative+0": "this Thu.",
	"field-thu-short-relative+1": "next Thu.",
	"field-quarter": "quarter",
	"field-month": "month",
	"field-weekOfMonth": "week of month",
	"field-tue-relative+0": "this Tuesday",
	"field-quarter-short-relative+0": "this qtr.",
	"field-tue-relative+1": "next Tuesday",
	"field-quarter-short-relative+1": "next qtr.",
	"field-fri-narrow-relative+0": "this F",
	"field-fri-narrow-relative+1": "next F",
	"field-fri-short-relative+-1": "last Fri.",
	"field-sun-narrow-relative+-1": "last Su",
	"field-quarter-short-relative+-1": "last qtr.",
	"field-dayOfYear-short": "day of yr.",
	"field-sun-narrow-relative+0": "this Su",
	"field-thu-narrow-relative+0": "this Th",
	"field-sun-narrow-relative+1": "next Su",
	"field-thu-narrow-relative+1": "next Th",
	"field-tue-narrow-relative+0": "this Tu",
	"field-mon-relative+0": "this Monday",
	"field-tue-narrow-relative+1": "next Tu",
	"field-mon-relative+1": "next Monday",
	"field-week-short-relative+-1": "last wk.",
	"field-tue-narrow-relative+-1": "last Tu",
	"field-second-short": "sec.",
	"field-second": "second",
	"field-fri-short-relative+0": "this Fri.",
	"field-sat-relative+-1": "last Saturday",
	"field-fri-short-relative+1": "next Fri.",
	"field-sun-relative+-1": "last Sunday",
	"field-month-short-relative+0": "this mo.",
	"field-month-relative+0": "this month",
	"field-month-short-relative+1": "next mo.",
	"field-weekdayOfMonth": "weekday of the month",
	"field-month-relative+1": "next month",
	"field-week-short-relative+0": "this wk.",
	"field-week-short-relative+1": "next wk.",
	"field-week": "week",
	"field-sat-short-relative+0": "this Sat.",
	"field-sat-short-relative+1": "next Sat.",
	"field-year-relative+0": "this year",
	"field-week-relative+-1": "last week",
	"field-year-relative+1": "next year",
	"field-year-short-relative+-1": "last yr.",
	"field-era-short": "era",
	"field-quarter-short": "qtr.",
	"field-sun-short-relative+-1": "last Sun.",
	"field-thu-short-relative+-1": "last Thu.",
	"field-tue-short-relative+-1": "last Tue.",
	"field-mon-relative+-1": "last Monday",
	"field-sat-narrow-relative+-1": "last Sa",
	"field-month-short-relative+-1": "last mo.",
	"field-week-relative+0": "this week",
	"field-sun-short-relative+0": "this Sun.",
	"field-second-short-relative+0": "now",
	"field-week-relative+1": "next week",
	"field-sun-short-relative+1": "next Sun."
}
//end v1.x content
);